@@ -161,6 +161,8 @@ private:
     map <string, PCIDevice *> pci_devices;
 };
 
+class Host;
+
 /**
  *  The HostShare class. It represents a logical partition of a host...
  */
@@ -175,6 +177,14 @@ public:
 
     ~HostShare(){};
 
+    /**
+     *  Rebuilds the object from an xml node
+     *    @param node The xml node pointer
+     *
+     *    @return 0 on success, -1 otherwise
+     */
+    int from_xml_node(const xmlNodePtr node);
+
     /**
      *  Add a new VM to this share
      *    @param vmid of the VM
@@ -216,7 +226,7 @@ public:
      *    @param pci_devs requested by the VM
      */
     void del(long long cpu, long long mem, long long disk,
-            vector<VectorAttribute *> pci_devs)
+            const vector<VectorAttribute *>& pci_devs)
     {
         cpu_usage  -= cpu;
         mem_usage  -= mem;
@@ -303,15 +313,65 @@ public:
         pci.set_monitorization(pci_att);
     }
 
+    /**
+     *  Resets capaity values of the share
+     */
+    void reset_capacity()
+    {
+        total_cpu = 0;
+        total_mem = 0;
+
+        max_cpu = 0;
+        max_mem = 0;
+
+        free_cpu = 0;
+        free_mem = 0;
+
+        used_cpu = 0;
+        used_mem = 0;
+    };
+
+    /**
+     * Set the capacity attributes of the share. CPU and Memory may reserve some
+     * capacity according to RESERVED_CPU and RESERVED_MEM. These values can be
+     * either absolute or a percentage.
+     *
+     * Share values are read from the Host template returned by the monitoring
+     * probes. The values are removed from the template.
+     *
+     *   @param host for this share, capacity values are removed from the template
+     *   @para cr_cpu, reserved cpu default cluster value
+     *   @para cluster_rmem, reserved mem default cluster value
+     */
+    void set_capacity(Host *host, const string& crcpu, const string& crmem);
+
+    /**
+     * Update the capacity attributes when the RESERVED_CPU and RESERVED_MEM
+     * are updated.
+     *   @param host for this share
+     */
+    void update_capacity(Host *host);
+
+    /**
+     *  Return the number of running VMs in this host
+     */
+    long long get_running_vms()
+    {
+        return running_vms;
+    };
+
 private:
 
     long long disk_usage; /**< Disk allocated to VMs (in MB).        */
     long long mem_usage;  /**< Memory allocated to VMs (in KB)       */
     long long cpu_usage;  /**< CPU  allocated to VMs (in percentage) */
 
+    long long total_mem;  /**< Total memory capacity (in KB)         */
+    long long total_cpu;  /**< Total cpu capacity (in percentage)    */
+
     long long max_disk;   /**< Total disk capacity (in MB)           */
-    long long max_mem;    /**< Total memory capacity (in KB)         */
-    long long max_cpu;    /**< Total cpu capacity (in percentage)    */
+    long long max_mem;    /**< Total memory capacity (in KB) +/- reserved     */
+    long long max_cpu;    /**< Total cpu capacity (in percentage) +/- reserved*/
 
     long long free_disk;  /**< Free disk from the IM monitor         */
     long long free_mem;   /**< Free memory from the IM monitor       */
@@ -325,21 +385,6 @@ private:
 
     HostShareDatastore ds;
     HostSharePCI       pci;
-
-    // ----------------------------------------
-    // Friends
-    // ----------------------------------------
-
-    friend class Host;
-    friend class HostPool;
-
-    /**
-     *  Rebuilds the object from an xml node
-     *    @param node The xml node pointer
-     *
-     *    @return 0 on success, -1 otherwise
-     */
-    int from_xml_node(const xmlNodePtr node);
 };
 
 #endif /*HOST_SHARE_H_*/
