@@ -25,7 +25,7 @@
 class RequestManagerAllocateDB: public Request
 {
 protected:
-    RequestManagerAllocateDB(): Request("AllocateDB", "A:ss",
+    RequestManagerAllocateDB(const string& name): Request(name, "A:ss",
             "Allocates a new object from its template representation")
     {
         auth_op = AuthRequest::MANAGE;
@@ -69,7 +69,7 @@ protected:
 class MarketPlaceAppAllocateDB: public RequestManagerAllocateDB
 {
 public:
-    MarketPlaceAppAllocateDB(): RequestManagerAllocateDB()
+    MarketPlaceAppAllocateDB():RequestManagerAllocateDB("one.marketapp.allocatedb")
     {
         auth_object = PoolObjectSQL::MARKETPLACEAPP;
         pool        =  Nebula::instance().get_apppool();
@@ -95,7 +95,7 @@ public:
 class MarketPlaceAllocateDB: public RequestManagerAllocateDB
 {
 public:
-    MarketPlaceAllocateDB(): RequestManagerAllocateDB()
+    MarketPlaceAllocateDB(): RequestManagerAllocateDB("one.market.allocatedb")
     {
         auth_object = PoolObjectSQL::MARKETPLACE;
         pool        =  Nebula::instance().get_marketpool();
