@@ -34,6 +34,8 @@ protected:
         :Request(method_name, "A:si", help)
     {
         auth_op = AuthRequest::USE;
+
+        leader_only = false;
     };
 
     ~RequestManagerInfo(){};
@@ -59,7 +61,7 @@ class VirtualMachineInfo : public RequestManagerInfo
 {
 public:
     VirtualMachineInfo():
-        RequestManagerInfo("VirtualMachineInfo",
+        RequestManagerInfo("one.vm.info",
                            "Returns virtual machine instance information")
     {
         Nebula& nd  = Nebula::instance();
@@ -84,7 +86,7 @@ class TemplateInfo : public RequestManagerInfo
 {
 public:
     TemplateInfo():
-        RequestManagerInfo("TemplateInfo",
+        RequestManagerInfo("one.template.info",
                            "Returns virtual machine template information")
     {
         Nebula& nd  = Nebula::instance();
@@ -108,7 +110,7 @@ class VirtualNetworkInfo: public RequestManagerInfo
 {
 public:
     VirtualNetworkInfo():
-        RequestManagerInfo("VirtualNetworkInfo",
+        RequestManagerInfo("one.vn.info",
                            "Returns virtual network information")
     {
         Nebula& nd  = Nebula::instance();
@@ -130,7 +132,7 @@ class ImageInfo: public RequestManagerInfo
 {
 public:
     ImageInfo():
-        RequestManagerInfo("ImageInfo",
+        RequestManagerInfo("one.image.info",
                            "Returns image information")
     {
         Nebula& nd  = Nebula::instance();
@@ -149,7 +151,7 @@ class HostInfo : public RequestManagerInfo
 {
 public:
     HostInfo():
-        RequestManagerInfo("HostInfo",
+        RequestManagerInfo("one.host.info",
                            "Returns host information")
     {
         Nebula& nd  = Nebula::instance();
@@ -167,7 +169,7 @@ class GroupInfo: public RequestManagerInfo
 {
 public:
     GroupInfo():
-        RequestManagerInfo("GroupInfo",
+        RequestManagerInfo("one.group.info",
                            "Returns group information")
     {
         Nebula& nd = Nebula::instance();
@@ -192,7 +194,7 @@ class UserInfo: public RequestManagerInfo
 {
 public:
     UserInfo():
-        RequestManagerInfo("UserInfo",
+        RequestManagerInfo("one.user.info",
                            "Returns user information")
     {
         Nebula& nd  = Nebula::instance();
@@ -217,7 +219,7 @@ class DatastoreInfo: public RequestManagerInfo
 {
 public:
     DatastoreInfo():
-        RequestManagerInfo("DatastoreInfo",
+        RequestManagerInfo("one.datastore.info",
                            "Returns datastore information")
     {
         Nebula& nd  = Nebula::instance();
@@ -235,7 +237,7 @@ class ClusterInfo: public RequestManagerInfo
 {
 public:
     ClusterInfo():
-        RequestManagerInfo("ClusterInfo",
+        RequestManagerInfo("one.cluster.info",
                            "Returns cluster information")
     {
         Nebula& nd = Nebula::instance();
@@ -253,7 +255,7 @@ class DocumentInfo : public RequestManagerInfo
 {
 public:
     DocumentInfo():
-        RequestManagerInfo("DocumentInfo",
+        RequestManagerInfo("one.document.info",
                            "Returns generic document information")
     {
         Nebula& nd  = Nebula::instance();
@@ -271,7 +273,7 @@ class ZoneInfo: public RequestManagerInfo
 {
 public:
     ZoneInfo():
-        RequestManagerInfo("ZoneInfo",
+        RequestManagerInfo("one.zone.info",
                            "Returns zone information")
     {
         Nebula& nd = Nebula::instance();
@@ -289,7 +291,7 @@ class SecurityGroupInfo : public RequestManagerInfo
 {
 public:
     SecurityGroupInfo():
-        RequestManagerInfo("SecurityGroupInfo",
+        RequestManagerInfo("one.secgroup.info",
                            "Returns security group information")
     {
         Nebula& nd  = Nebula::instance();
@@ -307,7 +309,7 @@ class VdcInfo: public RequestManagerInfo
 {
 public:
     VdcInfo():
-        RequestManagerInfo("VdcInfo",
+        RequestManagerInfo("one.vdc.info",
                            "Returns VDC information")
     {
         Nebula& nd = Nebula::instance();
@@ -325,7 +327,7 @@ class VirtualRouterInfo : public RequestManagerInfo
 {
 public:
     VirtualRouterInfo():
-        RequestManagerInfo("VirtualRouterInfo",
+        RequestManagerInfo("one.vrouter.info",
                            "Returns virtual router information")
     {
         Nebula& nd  = Nebula::instance();
@@ -343,7 +345,7 @@ class MarketPlaceInfo : public RequestManagerInfo
 {
 public:
     MarketPlaceInfo():
-        RequestManagerInfo("MarketPlaceInfo",
+        RequestManagerInfo("one.market.info",
                            "Returns marketplace information")
     {
         Nebula& nd  = Nebula::instance();
@@ -361,7 +363,7 @@ class MarketPlaceAppInfo : public RequestManagerInfo
 {
 public:
     MarketPlaceAppInfo():
-        RequestManagerInfo("MarketPlaceAppInfo",
+        RequestManagerInfo("one.marketapp.info",
                            "Returns marketplace app information")
     {
         Nebula& nd  = Nebula::instance();
@@ -371,7 +373,23 @@ public:
 
     ~MarketPlaceAppInfo(){};
 };
+
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
+class VMGroupInfo : public RequestManagerInfo
+{
+public:
+    VMGroupInfo():
+        RequestManagerInfo("one.vmgroup.info",
+                           "Returns vm group information")
+    {
+        Nebula& nd  = Nebula::instance();
+        pool        = nd.get_vmgrouppool();
+        auth_object = PoolObjectSQL::VMGROUP;
+    };
+
+    ~VMGroupInfo(){};
+};
+
 #endif
