@@ -243,6 +243,18 @@ public:
 		set(new SingleAttribute(name, value));
 	}
 
+	void add(const string& name, bool value)
+	{
+        if ( value )
+        {
+            set(new SingleAttribute(name, "YES"));
+        }
+        else
+        {
+            set(new SingleAttribute(name, "NO"));
+        }
+	}
+
     /**
      *  Removes an attribute from the template. The attributes are returned. The
      *  attributes MUST be freed by the calling funtion
@@ -326,15 +338,15 @@ public:
      *    @param name the attribute name.
      *    @return true first attribute or 0 if not found or wrong type
      */
-	inline const VectorAttribute * get(const string& name) const
-	{
-		return __get<VectorAttribute>(name);
-	}
+    inline const VectorAttribute * get(const string& name) const
+    {
+      return __get<VectorAttribute>(name);
+    }
 
-	inline VectorAttribute * get(const string& name)
-	{
-		return __get<VectorAttribute>(name);
-	}
+    inline VectorAttribute * get(const string& name)
+    {
+      return __get<VectorAttribute>(name);
+    }
 
     /**
      *  Gets the value of a SingleAttribute with the given name and converts
@@ -412,6 +424,14 @@ public:
       */
      virtual bool has_restricted();
 
+     /**
+      *  @return true if template is empty
+      */
+     bool empty()
+     {
+         return attributes.empty();
+     }
+
 protected:
     /**
      *  The template attributes
