@@ -1544,15 +1544,24 @@ public:
      *
      * @return 0 on success
      */
-    int set_active_snapshot(int snap_id);
+    int set_revert_snapshot(int snap_id);
+
+    int set_delete_snapshot(int snap_id);
+
+    /**
+     *  @return the on-going ACTION associated to the ACTIVE snapshot
+     */
+    string get_snapshot_action();
 
     /**
      * Replaces HYPERVISOR_ID for the active SNAPSHOT
      *
      * @param hypervisor_id Id returned by the hypervisor for the newly
-     * created snapshot
+     * created snapshot. The no hypervisor_id version uses the snap_id.
      */
-    void update_snapshot_id(string& hypervisor_id);
+    void update_snapshot_id(const string& hypervisor_id);
+
+    void update_snapshot_id();
 
     /**
      * Cleans the ACTIVE = YES attribute from the snapshots
