@@ -1162,7 +1162,6 @@ MARKETPLACE_DRIVER_S3_SCRIPTS="src/market_mad/remotes/s3/import \
 #-------------------------------------------------------------------------------
 
 ONEDB_FILES="src/onedb/fsck.rb \
-            src/onedb/import_slave.rb \
             src/onedb/onedb.rb \
             src/onedb/onedb_backend.rb \
             src/onedb/vcenter_one54.rb \
@@ -1208,7 +1207,8 @@ ONEDB_SHARED_MIGRATOR_FILES="src/onedb/shared/2.0_to_2.9.80.rb \
                              src/onedb/shared/4.6.0_to_4.11.80.rb \
                              src/onedb/shared/4.11.80_to_4.90.0.rb \
                              src/onedb/shared/4.90.0_to_5.2.0.rb \
-                             src/onedb/shared/5.2.0_to_5.3.80.rb"
+                             src/onedb/shared/5.2.0_to_5.3.80.rb \
+                             src/onedb/shared/5.3.80_to_5.4.0.rb"
 
 ONEDB_LOCAL_MIGRATOR_FILES="src/onedb/local/4.5.80_to_4.7.80.rb \
                             src/onedb/local/4.7.80_to_4.9.80.rb \
@@ -1217,7 +1217,8 @@ ONEDB_LOCAL_MIGRATOR_FILES="src/onedb/local/4.5.80_to_4.7.80.rb \
                             src/onedb/local/4.11.80_to_4.13.80.rb \
                             src/onedb/local/4.13.80_to_4.13.85.rb \
                             src/onedb/local/4.13.85_to_4.90.0.rb \
-                            src/onedb/local/4.90.0_to_5.3.80.rb"
+                            src/onedb/local/4.90.0_to_5.3.80.rb \
+                            src/onedb/local/5.3.80_to_5.4.0.rb"
 
 ONEDB_PATCH_FILES="src/onedb/patches/4.14_monitoring.rb \
                    src/onedb/patches/history_times.rb"
