@@ -48,7 +48,8 @@ class OpenNebula::LdapAuth
             :mapping_filename   => 'server1.yaml',
             :mapping_key        => 'GROUP_DN',
             :mapping_default    => 1,
-            :attributes         => [ "memberOf" ]
+            :attributes         => [ "memberOf" ],
+            :rfc2307bis         => true
         }.merge(options)
 
         ops={}
@@ -61,6 +62,10 @@ class OpenNebula::LdapAuth
             }
         end
 
+        if !@options[:rfc2307bis]
+            @options[:attributes] << @options[:user_field]
+        end
+
         ops[:host]=@options[:host] if @options[:host]
         ops[:port]=@options[:port].to_i if @options[:port]
         ops[:encryption]=@options[:encryption] if @options[:encryption]
@@ -181,9 +186,22 @@ class OpenNebula::LdapAuth
     def get_groups
         groups = []
 
-        [@user['memberOf']].flatten.each do |group|
-            if @mapping[group]
-                groups << @mapping[group]
+        if @options[:rfc2307bis]
+            [@user['memberOf']].flatten.each do |group|
+                if @mapping[group]
+                    groups << @mapping[group]
+                end
+            end
+        else
+            filter = "(#{@options[:group_field]}=#{@user[@options[:user_field]].first})"
+            @ldap.search(
+                :base       => @options[:base],
+                :attributes => "dn",
+                :filter     => filter
+            ) do |entry|
+                if @mapping[entry.dn]
+                    groups << @mapping[entry.dn]
+                end
             end
         end
 
