@@ -578,7 +578,7 @@ in the frontend machine.
             vm_disks = [vm_hash['VM']['TEMPLATE']['DISK']].flatten
         end
 
-        if vm.has_elements?("/VM/TEMPLATE/CONTEXT")
+        if vm.has_elements?("/VM/TEMPLATE/CONTEXT") && vm["/VM/HISTORY_RECORDS/HISTORY[1]/VM_MAD"] != 'vcenter'
             context_disk = vm_hash['VM']['TEMPLATE']['CONTEXT']
 
             context_disk["IMAGE"]     = "CONTEXT"
