@@ -35,7 +35,7 @@ extern "C" void * hm_action_loop(void *arg)
 
     hm = static_cast<HookManager *>(arg);
 
-    hm->am.loop(0,0);
+    hm->am.loop();
 
     NebulaLog::log("HKM",Log::INFO,"Hook Manager stopped.");
 
@@ -112,23 +112,3 @@ int HookManager::start()
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void HookManager::do_action(const string &action, void * arg)
-{
-    if (action == ACTION_FINALIZE)
-    {
-        NebulaLog::log("HKM",Log::INFO,"Stopping Hook Manager...");
-
-        MadManager::stop();
-    }
-    else
-    {
-        ostringstream oss;
-        oss << "Unknown action name: " << action;
-
-        NebulaLog::log("HKM", Log::ERROR, oss);
-    }
-}
-
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
