@@ -15,7 +15,6 @@
 /* -------------------------------------------------------------------------- */
 
 #include "InformationManager.h"
-#include "NebulaLog.h"
 #include "Cluster.h"
 #include "Nebula.h"
 
@@ -42,7 +41,7 @@ extern "C" void * im_action_loop(void *arg)
 
     im = static_cast<InformationManager *>(arg);
 
-    im->am.loop(im->timer_period,0);
+    im->am.loop(im->timer_period);
 
     NebulaLog::log("InM",Log::INFO,"Information Manager stopped.");
 
@@ -116,29 +115,6 @@ int InformationManager::start()
     return rc;
 }
 
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
-void InformationManager::do_action(const string &action, void * arg)
-{
-    if (action == ACTION_TIMER)
-    {
-        timer_action();
-    }
-    else if (action == ACTION_FINALIZE)
-    {
-        NebulaLog::log("InM",Log::INFO,"Stopping Information Manager...");
-
-        MadManager::stop();
-    }
-    else
-    {
-        ostringstream oss;
-        oss << "Unknown action name: " << action;
-
-        NebulaLog::log("InM", Log::ERROR, oss);
-    }
-}
 
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
@@ -179,7 +155,7 @@ int InformationManager::start_monitor(Host * host, bool update_remotes)
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-void InformationManager::timer_action()
+void InformationManager::timer_action(const ActionRequest& ar)
 {
     static int mark = 0;
 
