@@ -221,7 +221,7 @@ int MarketPlace::insert_replace(SqlDB *db, bool replace, string& error_str)
         <<          group_u             << ","
         <<          other_u             << ")";
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     db->free_str(sql_name);
     db->free_str(sql_xml);
