@@ -23,19 +23,23 @@ module OpenNebula
     #                  @<num>
     #                  ALL
     #     RESOURCE  -> + separated list and "/{#,@,%}<num>|ALL"
-    #                  VM,
+    #                  VM
     #                  HOST
     #                  NET
     #                  IMAGE
     #                  USER
     #                  TEMPLATE
     #                  GROUP
-    #                  ACL
+    #                  DATASTORE
+    #                  CLUSTER
+    #                  DOCUMENT
+    #                  ZONE
     #                  SECGROUP
     #                  VDC
     #                  VROUTER
     #                  MARKETPLACE
     #                  MARKETPLACEAPP
+    #                  VMGROUP
     #     RIGHTS    -> + separated list
     #                  USE
     #                  MANAGE
@@ -67,7 +71,8 @@ module OpenNebula
             "VDC"           =>  0x2000000000000,
             "VROUTER"       =>  0x4000000000000,
             "MARKETPLACE"   =>  0x8000000000000,
-            "MARKETPLACEAPP"=> 0x10000000000000
+            "MARKETPLACEAPP"=> 0x10000000000000,
+            "VMGROUP"       => 0x20000000000000
         }
 
         RIGHTS =
