@@ -447,6 +447,7 @@ void RequestManager::register_xml_methods()
     xmlrpc_c::methodPtr system_version(new SystemVersion());
     xmlrpc_c::methodPtr system_config(new SystemConfig());
     xmlrpc_c::methodPtr system_sql(new SystemSql());
+    xmlrpc_c::methodPtr system_sqlquery(new SystemSqlQuery());
 
     // Rename Methods
     xmlrpc_c::methodPtr vm_rename(new VirtualMachineRename());
@@ -1065,6 +1066,7 @@ void RequestManager::register_xml_methods()
     RequestManagerRegistry.addMethod("one.system.version", system_version);
     RequestManagerRegistry.addMethod("one.system.config", system_config);
     RequestManagerRegistry.addMethod("one.system.sql", system_sql);
+    RequestManagerRegistry.addMethod("one.system.sqlquery", system_sqlquery);
 };
 
 /* -------------------------------------------------------------------------- */
