@@ -118,6 +118,15 @@ Request::ErrorCode ImagePersistent::request_execute(
 
     ds_id = image->get_ds_id();
 
+    if ( !image->is_managed() )
+    {
+        att.resp_msg = "Cannot change persistent state for non-managed images";
+
+        image->unlock();
+
+        return ACTION;
+    }
+
     image->unlock();
 
     ds = dspool->get(ds_id, true);
