@@ -135,7 +135,7 @@ define(function(require) {
 
     $("div.vcpu_input", context).html(input);
 
-    if (Config.isFeatureEnabled("instanciate_cpu_factor")){
+    if (Config.isFeatureEnabled("instantiate_cpu_factor")){
       $("div.vcpu_input input", context).on("change", function(){
         var vcpuValue = $("div.vcpu_input input", context).val();
         $("div.cpu_input input", context).val(vcpuValue * Config.scaleFactor);
