@@ -1,5 +1,5 @@
 /* -------------------------------------------------------------------------- */
-/* Copyright 2002-2016, OpenNebula Project, OpenNebula Systems                */
+/* Copyright 2002-2017, OpenNebula Project, OpenNebula Systems                */
 /*                                                                            */
 /* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
 /* not use this file except in compliance with the License. You may obtain    */
@@ -19,8 +19,7 @@ define(function(require) {
     DEPENDENCIES
    */
 
-  var Locale = require('utils/locale');
-  var Accounting = require('utils/accounting');
+  var BasePanel = require('tabs/users-tab/panels/accounting-common');
 
   /*
     CONSTANTS
@@ -28,41 +27,20 @@ define(function(require) {
 
   var TAB_ID = require('../tabId');
   var PANEL_ID = require('./accounting/panelId');
-  var RESOURCE = "User";
-  var XML_ROOT = "USER";
 
   /*
     CONSTRUCTOR
    */
 
   function Panel(info) {
-    this.title = Locale.tr("Accounting");
-    this.icon = "fa-bar-chart-o";
+    this.tabId = TAB_ID;
 
-    this.element = info[XML_ROOT];
-
-    return this;
-  }
+    return BasePanel.call(this, info);
+  };
 
   Panel.PANEL_ID = PANEL_ID;
-  Panel.prototype.html = _html;
-  Panel.prototype.setup = _setup;
+  Panel.prototype = Object.create(BasePanel.prototype);
+  Panel.prototype.constructor = Panel;
 
   return Panel;
-
-  /*
-    FUNCTION DEFINITIONS
-   */
-
-  function _html() {
-    return Accounting.html();
-  }
-
-  function _setup(context) {
-    Accounting.setup(
-      context,
-      { fixed_user: this.element.ID,
-        init_group_by: "vm"
-      });
-  }
 });
