@@ -82,7 +82,7 @@ define(function(require) {
     Tips.setup(context);
     $( ".diskSlider", context).html(RangeSlider.html({
         min: that.diskSize,
-        max: Humanize.sizeToMB("500GB"),
+        max: Humanize.sizeToMB("500GB")*1024,
         initial: that.diskSize,
         name: "resize"
     }));
@@ -92,21 +92,32 @@ define(function(require) {
     $( ".uinput-slider", context).on("input", function(){
       $( ".uinput-slider-val",context).val(Humanize.size($( ".uinput-slider",context).val()));
       var cost = Humanize.sizeToMB($( ".uinput-slider",context).val())*that.diskCost;
+      if(isNaN(cost)){
+        cost = 0;
+      }
       document.getElementById("new_cost_resize").textContent =  Locale.tr("Cost")+": "+ convertCostNumber(cost);
     });
 
     $( ".uinput-slider-val", context).on("change", function(){
-      $( ".uinput-slider",context).val(Humanize.sizeToMB($( ".uinput-slider-val",context).val()));
+      $( ".uinput-slider",context).val(Humanize.sizeToMB(($( ".uinput-slider-val",context).val()).toString())*1024);
       var cost = Humanize.sizeToMB($( ".uinput-slider",context).val())*that.diskCost;
+      if(isNaN(cost)){
+        cost = 0;
+      }
       document.getElementById("new_cost_resize").textContent =  Locale.tr("Cost")+": "+ convertCostNumber(cost);
     });
 
     var cost = Humanize.sizeToMB($( ".uinput-slider",context).val())*this.diskCost;
+    if(isNaN(cost)){
+        cost = 0;
+    }
     document.getElementById("new_cost_resize").textContent =  Locale.tr("Cost")+": "+ convertCostNumber(cost);
 
 
     $('#' + DIALOG_ID + 'Form', context).submit(function() {
       var new_size = $( ".uinput-slider",context).val();
+      new_size = Math.round(parseInt(new_size) / 1024);
+      new_size = new_size.toString();
       var obj = {
         "vm_id": that.element.ID,
         "disk_id" : that.diskId,
