@@ -397,99 +397,6 @@ get '/vcenter/template/:vcenter_ref/:template_id' do
     end
 end
 
-get '/vcenter/wild/:vcenter_ref' do
-    begin
-        t        = {}
-        template = nil
-        vm_ref   = params[:vcenter_ref]
-        sunstone = true
-        wild     = true
-
-        if !vm_ref || vm_ref.empty?
-            msg = "No VM moref for Wild VM specified"
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        vc_uuid = vcenter_client.vim.serviceContent.about.instanceUuid
-
-        dpool = VCenterDriver::VIHelper.one_pool(OpenNebula::DatastorePool)
-        if dpool.respond_to?(:message)
-            msg = "Could not get OpenNebula DatastorePool: #{dpool.message}"
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        ipool = VCenterDriver::VIHelper.one_pool(OpenNebula::ImagePool)
-        if ipool.respond_to?(:message)
-            msg = "Could not get OpenNebula ImagePool: #{ipool.message}"
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        npool = VCenterDriver::VIHelper.one_pool(OpenNebula::VirtualNetworkPool)
-        if npool.respond_to?(:message)
-            msg = "Could not get OpenNebula VirtualNetworkPool: #{npool.message}"
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        hpool = VCenterDriver::VIHelper.one_pool(OpenNebula::HostPool)
-        if hpool.respond_to?(:message)
-            msg = "Could not get OpenNebula HostPool: #{hpool.message}"
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        vcenter_vm = VCenterDriver::VirtualMachine.new_from_ref(vm_ref, vcenter_client)
-        vm_name    = vcenter_vm["name"]
-
-        # Get disks information for template
-        error, template_disks = vcenter_vm.import_vcenter_disks(vc_uuid, dpool, ipool, sunstone)
-
-        if !error.empty?
-            msg = error
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        t[:disks] = template_disks
-
-        # Get nics information for template
-
-        # Create images or get nics information for template
-        error, template_nics = vcenter_vm.import_vcenter_nics(vc_uuid,
-                                                              npool,
-                                                              hpool,
-                                                              vcenter_client.vim.host,
-                                                              vm_ref,
-                                                              wild,
-                                                              sunstone,
-                                                              vm_name)
-
-        if !error.empty?
-            msg = error
-            logger.error("[vCenter] " + msg)
-            error = Error.new(msg)
-            error 404, error.to_json
-        end
-
-        t[:nics] = template_nics
-
-        [200, t.to_json]
-    rescue Exception => e
-        logger.error("[vCenter] " + e.message)
-        error = Error.new(e.message)
-        error 403, error.to_json
-    end
-end
-
 get '/vcenter/networks' do
     begin
         dc_folder = VCenterDriver::DatacenterFolder.new(vcenter_client)
