@@ -169,7 +169,7 @@ int User::insert_replace(SqlDB *db, bool replace, string& error_str)
         <<          other_u         << ")";
 
 
-    rc = db->exec(oss);
+    rc = db->exec_wr(oss);
 
     db->free_str(sql_username);
     db->free_str(sql_xml);
