@@ -360,7 +360,8 @@ class ClusterComputeResource
             "config.extraConfig", #VM extraconfig info e.g opennebula.vm.running
             "config.hardware.numCPU",
             "config.hardware.memoryMB",
-            "config.annotation"
+            "config.annotation",
+            "datastore"
         ]
 
         filterSpec = RbVmomi::VIM.PropertyFilterSpec(
@@ -429,6 +430,8 @@ class ClusterComputeResource
 
         get_resource_pool_list if !@rp_list
 
+        vm_pool = VCenterDriver::VIHelper.one_pool(OpenNebula::VirtualMachinePool)
+
         vms.each do |vm_ref,info|
             begin
                 vm = VCenterDriver::VirtualMachine.new_from_ref(vm_ref, @vi_client)
@@ -461,18 +464,22 @@ class ClusterComputeResource
                 number  = matches[1] if matches
 
                 # Extract vmid from ref and vcenter instance uuid if possible
+                one_vm = nil
                 if number == -1
                     one_vm = VCenterDriver::VIHelper.find_by_ref(OpenNebula::VirtualMachinePool,
                                                                 "DEPLOY_ID",
                                                                 vm_ref,
-                                                                vc_uuid)
-                    number = one_vm["ID"] if one_vm
-                end
+                                                                vc_uuid,
+                                                                vm_pool)
+                    if one_vm
+                        number = one_vm["ID"]
 
-                if number != -1
-                    next if @monitored_vms.include? number
-                    @monitored_vms << number
-                    vm.one_item if vm.get_vm_id
+                        next if @monitored_vms.include? number
+                        @monitored_vms << number
+
+                        vm.one_item = one_vm
+                        vm.vm_id = number
+                    end
                 end
 
                 vm.monitor(stats)
