@@ -34,29 +34,42 @@ def self.import_wild(host_id, vm_ref, one_vm, template)
         wild     = true
         sunstone = false
 
-        error, template_disks = vcenter_vm.import_vcenter_disks(vc_uuid, dpool, ipool, sunstone)
-        return OpenNebula::Error.new(error) if !error.empty?
+        #error, template_disks = vcenter_vm.import_vcenter_disks(vc_uuid, dpool, ipool, sunstone)
+        #return OpenNebula::Error.new(error) if !error.empty?
 
-        template << template_disks
+        #template << template_disks
 
         # Create images or get nics information for template
-        error, template_nics = vcenter_vm.import_vcenter_nics(vc_uuid,
-                                                              npool,
-                                                              hpool,
-                                                              vc_name,
-                                                              vm_ref,
-                                                              wild,
-                                                              sunstone,
-                                                              vm_name)
+        #error, template_nics = vcenter_vm.import_vcenter_nics(vc_uuid,
+        #                                                      npool,
+        #                                                      hpool,
+        #                                                      vc_name,
+        #                                                      vm_ref,
+        #                                                      wild,
+        #                                                      sunstone,
+        #                                                      vm_name)
+        #
+        #return OpenNebula::Error.new(error) if !error.empty?
 
-        return OpenNebula::Error.new(error) if !error.empty?
+        #template << template_nics
 
-        template << template_nics
+        # Get DS_ID for the deployment, the wild VM needs a System DS
+        dc_ref = vcenter_vm.get_dc.item._ref
+        ds_ref = template.match(/^VCENTER_DS_REF *= *"(.*)" *$/)[1]
+
+        ds_one = dpool.select do |e|
+            e["TEMPLATE/TYPE"]                == "SYSTEM_DS" &&
+            e["TEMPLATE/VCENTER_DS_REF"]      == ds_ref &&
+            e["TEMPLATE/VCENTER_DC_REF"]      == dc_ref &&
+            e["TEMPLATE/VCENTER_INSTANCE_ID"] == vc_uuid
+        end.first
+        
+        return OpenNebula::Error.new("DS with ref #{ds_ref} is not imported in OpenNebula, aborting Wild VM import.") if !ds_one
 
         rc = one_vm.allocate(template)
         return rc if OpenNebula.is_error?(rc)
 
-        rc = one_vm.deploy(host_id, false)
+        rc = one_vm.deploy(host_id, false, ds_one.id)
         return rc if OpenNebula.is_error?(rc)
 
         # Set reference to template disks and nics in VM template
@@ -958,4 +971,4 @@ end
 
 end # Importer
 
-end # module VCenterDriver
\ No newline at end of file
+end # module VCenterDriver
